@@ -5,13 +5,13 @@
 """The markdown2 test suite entry point."""
 
 import os
-from os.path import exists, join, abspath, dirname, normpath
+from os.path import join, abspath, dirname
 import sys
 import logging
 
 import testlib
 
-
+log = logging.getLogger("test")
 testdir_from_ns = {
     None: os.curdir,
 }
@@ -21,19 +21,28 @@ def setup():
     lib_dir = join(top_dir, "lib")
     sys.path.insert(0, lib_dir)
 
-    pygments_dir = join(top_dir, "externals", "pygments")
-    if exists(pygments_dir):
-        sys.path.insert(0, pygments_dir)
+    # Attempt to get 'pygments' on the import path.
+    try:
+        # If already have it, use that one.
+        import pygments  # noqa
+    except ImportError:
+        pygments_dir = join(top_dir, "deps", "pygments")
+        if sys.version_info[0] <= 2:
+            sys.path.insert(0, pygments_dir)
+        else:
+            sys.path.insert(0, pygments_dir + "3")
 
 if __name__ == "__main__":
-    default_tags = ["-knownfailure"]
+    logging.basicConfig()
+
+    setup()
+    default_tags = []
     try:
-        import pygments
+        import pygments  # noqa
     except ImportError:
-        # Skip pygments tests.
+        log.warning("skipping pygments tests ('pygments' module not found)")
         default_tags.append("-pygments")
+
     retval = testlib.harness(testdir_from_ns=testdir_from_ns,
-                             setup_func=setup,
                              default_tags=default_tags)
     sys.exit(retval)
-
